==> haskell-generic-trie-0.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-trie
version: 0.3.1
id: generic-trie-0.3.1-5ykZG7toRmb18ESjHbUYtR
key: generic-trie-0.3.1-5ykZG7toRmb18ESjHbUYtR
license: BSD3
maintainer: emertens@gmail.com
homepage: http://github.com/glguy/tries
synopsis: A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.
category: Data
author: Eric Mertens
exposed: True
indefinite: False
exposed-modules:
    Data.GenericTrie Data.GenericTrie.Internal
abi: b0d72818082e7556efa67e026f624d7c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/generic-trie-0.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/generic-trie-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/generic-trie-0.3.1
hs-libraries: HSgeneric-trie-0.3.1-5ykZG7toRmb18ESjHbUYtR
depends:
    base-4.10.1.0 transformers-0.5.2.0 containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock
haddock-html: /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-trie-0.3.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-trie
version: 0.3.1
id: generic-trie-0.3.1-E6Wir4h39HG7zFiv8mChx0
key: generic-trie-0.3.1-E6Wir4h39HG7zFiv8mChx0
license: BSD-3-Clause
maintainer: emertens@gmail.com
author: Eric Mertens
homepage: http://github.com/glguy/tries
synopsis: A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.
category: Data
abi: a6ac9c5fb1f3f8054975f577a246e78d
exposed: True
exposed-modules:
    Data.GenericTrie Data.GenericTrie.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/generic-trie-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/generic-trie-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/generic-trie-0.3.1
hs-libraries: HSgeneric-trie-0.3.1-E6Wir4h39HG7zFiv8mChx0
depends:
    base-4.11.1.0 transformers-0.5.5.0 containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock
haddock-html: /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
